==> cherokee-0.4.3-pre8.tar.gz: cherokee-0.4.3/src/common.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2003 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <stdarg.h>

#include "common.h"
#include "log.h"

/* Global mini-buffer for quickly use
 */
char gbl_buffer[gbl_buffer_size];



/* char *  */
/* stristr (char * s1, char * s2) */
/* { */
/* 	   char * ptr = s1; */

/* 	   if (!s1 || !s2 || !*s2) return s1; */

/* 	   while (*ptr) { */
/* 			 if (TOUPPER(*ptr) == TOUPPER(*s2)) { */
/* 				    char * cur1 = ptr + 1; */
/* 				    char * cur2 = s2 + 1; */
/* 				    while (*cur1 && *cur2 && TOUPPER(*cur1) == TOUPPER(*cur2)) { */
/* 						  cur1++; */
/* 						  cur2++; */
/* 				    } */
/* 				    if (!*cur2)	return ptr; */
/* 			 } */
/* 			 ptr++; */
/* 	   } */
/* 	   return NULL; */
/* } */


int
hexit (char c)
{
	if ( c >= '0' && c <= '9' )
		return c - '0';
	if ( c >= 'a' && c <= 'f' )
		return c - 'a' + 10;
	if ( c >= 'A' && c <= 'F' )
		return c - 'A' + 10;

	/* shouldn't happen, we're guarded by isxdigit() */
	return 0;           
}


void 
PRINT_ERROR (const char *format, ...)
{
	va_list arg_list;
	
	va_start(arg_list, format);

	/* Print in the stderr and in the log
	 */
	vfprintf(stderr, format, arg_list);
	vsyslog (LOG_ERR, format, arg_list);

	va_end(arg_list);
}

==> cherokee-0.4.4-pre4.tar.gz: cherokee-0.4.4/src/common.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2003 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <stdarg.h>
#include <stdlib.h>
#include <string.h>
#include <dlfcn.h>

#include "common.h"
#include "log.h"

/* Global mini-buffer for quickly use
 */
char gbl_buffer[gbl_buffer_size];


/* char *  */
/* stristr (char * s1, char * s2) */
/* { */
/* 	   char * ptr = s1; */

/* 	   if (!s1 || !s2 || !*s2) return s1; */

/* 	   while (*ptr) { */
/* 			 if (TOUPPER(*ptr) == TOUPPER(*s2)) { */
/* 				    char * cur1 = ptr + 1; */
/* 				    char * cur2 = s2 + 1; */
/* 				    while (*cur1 && *cur2 && TOUPPER(*cur1) == TOUPPER(*cur2)) { */
/* 						  cur1++; */
/* 						  cur2++; */
/* 				    } */
/* 				    if (!*cur2)	return ptr; */
/* 			 } */
/* 			 ptr++; */
/* 	   } */
/* 	   return NULL; */
/* } */


int
hexit (char c)
{
	if ( c >= '0' && c <= '9' )
		return c - '0';
	if ( c >= 'a' && c <= 'f' )
		return c - 'a' + 10;
	if ( c >= 'A' && c <= 'F' )
		return c - 'A' + 10;

	/* shouldn't happen, we're guarded by isxdigit() */
	return 0;           
}


void 
PRINT_ERROR (const char *format, ...)
{
	va_list arg_list;
	
	va_start(arg_list, format);

	/* Print in the stderr and in the log
	 */
	vfprintf(stderr, format, arg_list);

#ifdef HAVE_VSYSLOG
	vsyslog (LOG_ERR, format, arg_list);
#endif /* HAVE_VSYSLOG */

	va_end(arg_list);
}


void *
get_sym_from_dylib (char *dylib, char *sym)
{
	void  *lib;
	int    dl_flags;
	void  *ret;
	
	/* Load the library
	 */	

#ifdef HAVE_RTLDNOW
	dl_flags = RTLD_NOW;
#else
	dl_flags = RTLD_LAZY;
#endif

#ifdef HAVE_RTLDGLOBAL
	dl_flags |= RTLD_GLOBAL;
#endif

	/* Maybe the sym is accessible
	 */
	if ((ret = dlsym(NULL, sym)) != NULL) return ret;

	/* Open the library
	 */
	snprintf (gbl_buffer, gbl_buffer_size, CHEROKEE_PLUGINDIR "/%s", dylib);

	lib = dlopen (gbl_buffer, dl_flags);
	if (lib == NULL) {
		fprintf (stderr, "dlopen (%s): %s\n", gbl_buffer, dlerror());
		return NULL;
	}

	/* Get the sym
	 */
	ret = (void *) dlsym(lib, sym);
	if (ret == NULL) {
		fprintf (stderr, "dlsym (%s, %s): %s\n", gbl_buffer, sym, dlerror());
		return NULL;
	}
	
	return ret;
}
